<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Pasha L. Topchiyev <pasha@itopchiyev.com>
 * @author Elchin <quliyev_elchin1989@mail.ru>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '«';
$lang['doublequoteclosing']    = '»';
$lang['singlequoteopening']    = '„';
$lang['singlequoteclosing']    = '“';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Səhifəyə düzəliş et';
$lang['btn_source']            = 'Səhifənin ilkin mətnini göstər';
$lang['btn_show']              = 'Səhifəni göstər';
$lang['btn_create']            = 'Səhifəni yarat';
$lang['btn_search']            = 'Axtarış';
$lang['btn_save']              = 'Yadda saxla';
$lang['btn_preview']           = 'Baxış';
$lang['btn_top']               = 'Yuxarı';
$lang['btn_newer']             = '<< daha təzələr';
$lang['btn_older']             = 'daha köhnələr >>';
$lang['btn_revs']              = 'Səhifənin tarixçəsi';
$lang['btn_recent']            = 'Yaxın dəyişiklər';
$lang['btn_upload']            = 'Serverə yükə';
$lang['btn_cancel']            = 'İmtina';
$lang['btn_index']             = 'Bütün səhifələr';
$lang['btn_secedit']           = 'Düzəliş et';
$lang['btn_login']             = 'Giriş';
$lang['btn_logout']            = 'Cıxış';
$lang['btn_admin']             = 'İdarəetmə';
$lang['btn_update']            = 'Yenilə';
$lang['btn_delete']            = 'Sil';
$lang['btn_back']              = 'Geri';
$lang['btn_backlink']          = 'Bura olan link-lər';
$lang['btn_subscribe']         = 'Abunə ol (bütün dəyişiklər)';
$lang['btn_profile']           = 'Profil';
$lang['btn_reset']             = 'Boşalt';
$lang['btn_draft']             = 'Qaralamada düzəliş etmək';
$lang['btn_recover']           = 'Qaralamanı qaytar';
$lang['btn_draftdel']          = 'Qaralamanı sil';
$lang['btn_revert']            = 'Qaytar';
$lang['btn_register']          = 'Qeydiyyatdan keç';
$lang['btn_img_backto']        = 'Qayıd %s';
$lang['loggedinas']            = 'İstifadəcinin adı:';
$lang['user']                  = 'istifadəci adı';
$lang['pass']                  = 'Şifrə';
$lang['newpass']               = 'Yeni şifrə';
$lang['oldpass']               = 'Hazırki şifrəni daxil edin';
$lang['passchk']               = 'təkrarlayın';
$lang['remember']              = 'Məni yadda saxla';
$lang['fullname']              = 'Tam ad';
$lang['email']                 = 'E-Mail';
$lang['profile']               = 'İstifadəçi profili';
$lang['badlogin']              = 'Təssüf ki istifadəçi adı və ya şifrə səhvdir.';
$lang['minoredit']             = 'Az dəyişiklər';
$lang['draftdate']             = 'Qaralama yadda saxlandı';
$lang['nosecedit']             = 'Bu vaxt ərzində səhifə dəyişilmişdir, və bölmə haqqında məlumat köhnəlmişdir. Səhifənin tam versiyası yüklənmişdir.';
$lang['regmissing']            = 'Təssüf ki Siz bütün xanələri doldurmalısınız.';
$lang['reguexists']            = 'Təssüf ki bu ad ilə istifadəçi artıq mövcuddur.';
$lang['regsuccess']            = 'İstivadəci yaradıldı və şifrə sizin e-maila göndərildi.';
$lang['regsuccess2']           = 'İstifadəçi yaradıldı.';
$lang['regmailfail']           = 'Deyəsən, xəta şifrə e-maila göndərildikdə baş verdi. Xaiş olunur, ki administrator ilə əlaqə saxlayasınız!';
$lang['regbadmail']            = 'Deyəsən, daxil edilmiş e-mail ünvanı səhvdir. Əgər şübhəniz var isə administrator ilə əlaqə saxlayın.';
$lang['regbadpass']            = 'Daxil edilmiş iki şifrə fərqlidir. Xaiş olunur ki, yenidən daxil edəsiniz.';
$lang['regpwmail']             = 'Sizin DokuWiki sistemi üçün şifrəniz';
$lang['reghere']               = 'Sizin hələ istifadəçi adınız yoxdur? Buyurun əldə edin';
$lang['profna']                = 'Bu wiki profilin dəyişdirilməsini dəstəkləmir';
$lang['profnochange']          = 'Dəyişiklər edilmədi, profil yenilənmədi.';
$lang['profnoempty']           = 'istifadəci adı və e-mail ünvanı boş ola bilməz.';
$lang['profchanged']           = 'İstifadəçi profili uğurla yeniləndi.';
$lang['profdeleteuser']        = 'Profili sil.';
$lang['profconfdeletemissing'] = 'Təsdiq xanası seçilməib.';
$lang['proffail']              = 'İstifadəçi profili yenilənmiyib.';
$lang['pwdforget']             = 'Şifrəni yaddan çıxartmısız? Buyurun yenisini əldə edin';
$lang['resendna']              = 'Bu wiki şifrəni yenidən göndərməyi dəstəkləmir.';
$lang['resendpwdmissing']      = 'Formanın bütün xanəlırini doldurun.';
$lang['resendpwdnouser']       = 'Verilənlər bazasında bu ad ilə istifadəçi tapılmadı.';
$lang['resendpwdbadauth']      = 'Ativləşdirmə kodu səhvdir. Link-i tam olaraq köçürdüyünüzü yoxlayın. ';
$lang['resendpwdconfirm']      = 'Şifrəni təstiqləmək üçün sizin e-maila link göndərilmişdir. ';
$lang['resendpwdsuccess']      = 'Yeni şifrəniz e-maila göndərildi.';
$lang['license']               = 'Fərqli şey göstərilmiş hallardan başqa, bu wiki-nin mətni aşağıda göstərilmiş lisenziyanın şərtlərinə uyğun təqdim olunur:';
$lang['licenseok']             = 'Qeyd: bu səhifəni düzəliş edərək, Siz elədiyiniz düzəlişi aşağıda göstərilmiş lisenziyanın şərtlərinə uyğun istifadəsinə razılıq verirsiniz:';
$lang['searchmedia']           = 'Faylın adına görə axtarış:';
$lang['searchmedia_in']        = '%s-ın içində axtarış';
$lang['txt_upload']            = 'Serverə yükləmək üçün fayl seçin:';
$lang['txt_filename']          = 'Faylın wiki-də olan adını daxil edin (mütləq deyil):';
$lang['txt_overwrt']           = 'Mövcud olan faylın üstündən yaz';
$lang['lockedby']              = 'В данный момент заблокирован Bu an blokdadır:';
$lang['lockexpire']            = 'Blok bitir:';
$lang['js']['willexpire']      = 'Sizin bu səhifədə dəyişik etmək üçün blokunuz bir dəqiqə ərzində bitəcək.\nMünaqişələrdən yayınmaq və blokun taymerini sıfırlamaq üçün, baxış düyməsini sıxın.';
$lang['js']['notsavedyet']     = 'Yaddaşa verilməmiş məlumatlar itəcək.';
$lang['js']['searchmedia']     = 'Faylların axtarışı';
$lang['js']['keepopen']        = 'Seçimdən sonra pəncərəni açıq saxlamaq';
$lang['js']['hidedetails']     = 'Təfərruatı gizlət';
$lang['js']['mediadisplay']    = 'Link növü';
$lang['js']['mediasize']       = 'Şəkil ölçüsü.';
$lang['js']['mediaclose']      = 'Bağla.';
$lang['js']['mediadisplayimg'] = 'Şəkili göstər.';
$lang['js']['mediadisplaylnk'] = 'Ancaq linki göstər.';
$lang['js']['mediasmall']      = 'Kiçik versiya.';
$lang['js']['mediamedium']     = 'Orta versiya.';
$lang['js']['medialarge']      = 'Böyük versiya.';
$lang['js']['mediaoriginal']   = 'Orjinal versiya.';
$lang['js']['medialnk']        = 'Məlumat səhifəsinə keçid.';
$lang['js']['nosmblinks']      = 'Windows-un şəbəkə qovluqlarına link ancaq Internet Explorer-dən işləyir. \nAmma Siz linki köçürə bilərsiniz.';
$lang['js']['linkwiz']         = 'Linklər köməkçisi';
$lang['js']['linkto']          = 'Link göstərir:';
$lang['js']['del_confirm']     = 'Siz əminsiz ki, seçilmişləri silmək istəyirsiniz?';
$lang['rssfailed']             = 'Aşağıda göstərilmiş xəbər lentini əldə edən zaman xəta baş verdi: ';
$lang['nothingfound']          = 'Heçnə tapılmadı.';
$lang['mediaselect']           = 'Mediya-faylın seçilməsi';
$lang['uploadsucc']            = 'Yüklənmə uğur ilə başa çatdı';
$lang['uploadfail']            = 'Yüklənmə zamanı xəta baş veri. Bəlkə giriş haqları ilə problem var?';
$lang['uploadwrong']           = 'Yuklənməyə qadağa qoyuldu. Belə növlu faylları serverə yükləmək olmaz. ';
$lang['uploadexist']           = 'Bu adlı fayl artıq serverdə var. Yükləmə alınmadı .';
$lang['uploadbadcontent']      = 'Faylın tərkibi %s növünə uyğun gəlmir.';
$lang['uploadspam']            = 'Yüklənmə spam-filtri tərəfindən dayandırıldı.';
$lang['uploadxss']             = 'Yüklənmə təhlükəsizlik nəzərindən dayandırılmışdır.';
$lang['uploadsize']            = 'Yüklənilmiş fayl çox boyükdür. (maks. %s)';
$lang['deletesucc']            = '"%s" adlı fayl silindi.';
$lang['deletefail']            = '"%s" adlı fayl silinmədi. Faylın giriş haqlarını yoxlayın.';
$lang['mediainuse']            = '"%s" adlı fayl silinmədi. Fayl hələ istifadə olunur';
$lang['namespaces']            = 'Namespace-lər';
$lang['mediafiles']            = 'Mövcud olan fayllar';
$lang['mediausage']            = 'Bu fayla link yaratmaq üçün aşağıdakı sintaksisdən istifadə edin:';
$lang['mediaview']             = 'Bu faylın ilkinə bax';
$lang['mediaroot']             = 'kök';
$lang['mediaupload']           = 'Burda faylı hazırki qovluqa yükləmək olar ("namespace"). Alt qovluqlar yaratmaq üçün, onların adlarını faylın adının avvəlinə artırın ("Adla yükləmək"). Alt qovluqların adları çütnöqtə ilə ayrılır. ';
$lang['mediaextchange']        = 'Faylın nüvü .%s -dan .%s -ya dəyişdi!';
$lang['reference']             = 'Linklər göstərir';
$lang['ref_inuse']             = 'Bu fayl silinə bilməz, çünki o aşağıdaki səhifələr tərəfindən istifadə olunur:';
$lang['ref_hidden']            = 'Bəzi link-lər sizin oxumaq haqqınız olmayan səhifələrdə yerləşir';
$lang['hits']                  = 'uyğunluqlar';
$lang['quickhits']             = 'Səhifələrin adlarında uyğunluqlar';
$lang['toc']                   = 'Mündəricat';
$lang['current']               = 'hazırki';
$lang['yours']                 = 'Sizin versiyanız';
$lang['diff']                  = 'hazırki versiyadan fərqləri göstər';
$lang['diff2']                 = 'Versiyaların arasındaki fərqləri göstər  ';
$lang['line']                  = 'Sətr';
$lang['breadcrumb']            = 'Siz ziyarət etdiniz:';
$lang['youarehere']            = 'Siz burdasınız:';
$lang['lastmod']               = 'Son dəyişiklər:';
$lang['by']                    = ' Kimdən';
$lang['deleted']               = 'silinib';
$lang['created']               = 'yaranıb';
$lang['restored']              = 'köhnə versiya qaytarıldı (%s)';
$lang['external_edit']         = 'bayırdan dəyişik';
$lang['summary']               = 'Dəyişiklər xülasəsi';
$lang['noflash']               = 'Bu məzmuna baxmaq üçün <a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a> tələb olunur.';
$lang['download']              = 'Kodu yüklə';
$lang['mail_newpage']          = 'səhifə əlavə olundu:';
$lang['mail_changed']          = 'səhifəyə düzəliş edildi:';
$lang['mail_new_user']         = 'yeni istifadəçi:';
$lang['mail_upload']           = 'fayl yükləndi:';
$lang['qb_bold']               = 'Qalın şrift';
$lang['qb_italic']             = 'Maili şrift';
$lang['qb_underl']             = 'Alt-xətt';
$lang['qb_code']               = 'Kodun mətni';
$lang['qb_strike']             = 'Pozulmuş şrift';
$lang['qb_h1']                 = '1 dərəcəli başlıq';
$lang['qb_h2']                 = '2 dərəcəli başlıq';
$lang['qb_h3']                 = '3 dərəcəli başlıq';
$lang['qb_h4']                 = '4 dərəcəli başlıq';
$lang['qb_h5']                 = '5 dərəcəli başlıq';
$lang['qb_h']                  = 'Başlıq';
$lang['qb_hs']                 = 'Başlıq seçimi';
$lang['qb_hplus']              = 'Daha yüksək dərəcəli başlıq';
$lang['qb_hminus']             = 'Daha aşağı dərəcəli başlıq (altbaşlıq)';
$lang['qb_hequal']             = 'Hazırki dərəcəli başlıq';
$lang['qb_link']               = 'İç link';
$lang['qb_extlink']            = 'Bayır link';
$lang['qb_hr']                 = 'Bölücü';
$lang['qb_ol']                 = 'Nömrələnmiş siyahının element';
$lang['qb_ul']                 = 'Nömrələnməmiş siyahının element';
$lang['qb_media']              = 'Şəkillər və başqa fayllar əlavə et';
$lang['qb_sig']                = 'İmza at';
$lang['qb_smileys']            = 'Smayllar';
$lang['qb_chars']              = 'Xüsusi simvollar';
$lang['upperns']               = 'Ana namespace-ə keç';
$lang['metaedit']              = 'Meta-məlumatlarda düzəliş et';
$lang['metasaveerr']           = 'Meta-məlumatları yazan zamanı xəta';
$lang['metasaveok']            = 'Meta-məlumatlar yadda saxlandı';
$lang['img_title']             = 'Başlıq:';
$lang['img_caption']           = 'İmza:';
$lang['img_date']              = 'Tarix:';
$lang['img_fname']             = 'Faylın adı:';
$lang['img_fsize']             = 'Boy:';
$lang['img_artist']            = 'Şkilin müəllifi:';
$lang['img_copyr']             = 'Müəllif hüquqları:';
$lang['img_format']            = 'Format:';
$lang['img_camera']            = 'Model:';
$lang['img_keywords']          = 'Açar sözlər:';
$lang['authtempfail']          = 'İstifadəçilərin autentifikasiyası müvəqqəti dayandırılıb. Əgər bu problem uzun müddət davam edir sə, administrator ilə əlaqə saxlayın.';
$lang['i_chooselang']          = 'Dili seçin/Language';
$lang['i_installer']           = 'DokuWiki quraşdırılır';
$lang['i_wikiname']            = 'wiki-nin adı';
$lang['i_enableacl']           = 'Haqlar kontrolu siyahısının istifadəsinə icazə ver (tövsiyə edilir)';
$lang['i_superuser']           = 'Super-istifadəci';
$lang['i_problems']            = 'Quraşdırma proqramı aşağıdakı problemlər ilə üzləşdi. Davam etmək üçün onları həll etmək lazımdır. ';
$lang['i_modified']            = 'Təhlükəsizlik baxımından bu proqram ancaq yeni, dəyişməmiş halda olan DokuWiki üzərində işləyir.
                         Siz ya yüklənmiş quraşdırma paketini yenidən açmalısınız, ya da <a href="https://www.dokuwiki.org/install">DokuWiki-nin tam quraşdırma instruksiyasına</a> müraciyət etməlisiniz';
$lang['i_funcna']              = 'PHP-nin <code>%s</code> funksiyası mövcud deyil. Bəlkə, o hansı sa səbəbdən sizin host-unuz tərəfindən blok edilib?';
$lang['i_phpver']              = 'Sizin PHP-nin versiyası (<code>%s</code>) tələb olunan versiyadan aşagıdır (<code>%s</code>). Quraşdırılmış PHP-nin versiyasını yeniləyin.';
$lang['i_permfail']            = '<code>%s</code> DokuWiki-yə yazı üçün bağlıdır. Bu qovluğun giriş haqlarını yoxlamaq lazımdır!';
$lang['i_confexists']          = '<code>%s</code> artıq mövcuddur';
$lang['i_writeerr']            = '<code>%s</code> yaradıla bilmədi. Faylın/qovluqların giriş haqlarını yaxlamaq lazımdır. Və faylı əl ilə yaradın. ';
$lang['i_badhash']             = 'dokuwiki.php tanıla bilmir və ya dəyişdirilmişdir (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - səhv ya boş qiymətdir';
$lang['i_success']             = 'Konfiqurasiya uğurla başa çatdı. İndi siz install.php faylını silə bilərsiniz.
                        <a href="doku.php?id=wiki:welcome">Yeni DokuWiki-nizə</a> xoş gəlmişsiniz!';
$lang['i_failure']             = 'Konfiqurasiya fayllarına məlumat yazan zaman səhvlər tapıldı. Yəgin ki, <a href="doku.php?id=wiki:welcome">yeni DokuWiki-nizi</a> istifadə etmədən öncə, Siz o xətaları əl ilə düzəltməli olacaqsınız.';
$lang['i_policy']              = 'İlkin giriş haqları siyasəti';
$lang['i_pol0']                = 'Tam açıq wiki (oxumaq, yazmaq, fayl yükləmək hamıya olar)';
$lang['i_pol1']                = 'Acıq wiki (oxumaq hamıya olar, yazmaq və fayl yükləmək ancaq üzv olan istifadəçilərə olar)';
$lang['i_pol2']                = 'Bağlı wiki (uxumaq, yazmaq və yükləmək ancaq üzv olan istifadəçilərə olar)';
$lang['i_retry']               = 'Cəhdi təkrarla';
$lang['recent_global']         = '<b>%s</b> namespace-də baş vermiş dəyışıklərə baxırsınız. Siz həmçinin <a href="%s">wiki-də bu yaxında baş vermiş bütün dəyişiklərə</a> baxa bilərsiniz.';
$lang['years']                 = '%d il əvvəl';
$lang['months']                = '%d ay əvvəl';
$lang['weeks']                 = '%d həftə əvvəl';
$lang['days']                  = '%d gün əvvəl';
$lang['hours']                 = '%d saat əvvəl';
$lang['minutes']               = '%d dəqiqə əvvəl';
$lang['seconds']               = '%d saniyə əvvəl';
$lang['email_signature_text']  = 'DokuWiki aşağıdakı adresdə yerləşir
@DOKUWIKIURL@';
